@@ -29,7 +29,6 @@
 #include <KVBox>
 #include <QCheckBox>
 #include <QLabel>
-#include <QPainter>
 #include <QTableView>
 #include <QVBoxLayout>
 
@@ -37,7 +36,7 @@ using namespace KgpgCore;
 
 KgpgSelectPublicKeyDlg::KgpgSelectPublicKeyDlg(QWidget *parent, KGpgItemModel *model, const KShortcut &goDefaultKey, const bool hideasciioption, const KUrl::List &files)
 	: KDialog(parent),
-	m_customoptions(NULL),
+	m_customoptions(Q_NULLPTR),
 	imodel(model),
 	m_files(files),
 	m_hideasciioption(hideasciioption)
@@ -51,13 +50,13 @@ KgpgSelectPublicKeyDlg::KgpgSelectPublicKeyDlg(QWidget *parent, KGpgItemModel *m
 
     switch (fcount) {
     case 0:
-	setCaption(i18n("Select Public Key"));
+	setWindowTitle(i18n("Select Public Key"));
 	break;
     case 1:
-	setCaption(i18n("Select Public Key for %1", files.first().fileName()));
+	setWindowTitle(i18n("Select Public Key for %1", files.first().fileName()));
 	break;
     default:
-	setCaption(i18np("Select Public Key for %2 and one more file", "Select Public Key for %2 and %1 more files", files.count() - 1, files.first().fileName()));
+	setWindowTitle(i18np("Select Public Key for %2 and one more file", "Select Public Key for %2 and %1 more files", files.count() - 1, files.first().fileName()));
     }
 
     QWidget *page = new QWidget(this);
@@ -233,11 +232,9 @@ void KgpgSelectPublicKeyDlg::slotUntrusted(const bool state)
 void KgpgSelectPublicKeyDlg::slotGotoDefaultKey()
 {
 	KGpgNode *nd = imodel->getRootNode()->findKey(KGpgSettings::defaultKey());
-	if (nd == NULL)
+	if (nd == Q_NULLPTR)
 		return;
 	QModelIndex sidx = imodel->nodeIndex(nd);
 	QModelIndex pidx = iproxy->mapFromSource(sidx);
 	m_keyslist->selectionModel()->setCurrentIndex(pidx, QItemSelectionModel::Clear | QItemSelectionModel::SelectCurrent | QItemSelectionModel::Rows);
 }
-
-#include "selectpublickeydialog.moc"
